@@ -223,11 +223,12 @@ class Postgres_Handler:
         
          #checks for the table name in args
         if self.table_name_key not in kwargs:
+            print("Error: table_name required as argument")
             assert("Error: table_name required as argument")
         table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query_string= "UPDATE {table_name} SET"
+        query_string= f"UPDATE {table_name} SET"
         
         for key, value in kwargs.items():
             if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
@@ -242,8 +243,7 @@ class Postgres_Handler:
         query_string += f' WHERE "ID"=%(Id)s'
         values_dict[id_key] = kwargs[id_key]
         
-        sql_query = sql.SQL(query_string).format(sql.Identifier(table_name = kwargs[self.table_name_key]))
-        results = self.__run_query(sql_query)
+        results = self.__run_query(query_string)
         
         return self.__format_results(results)
     
